@@ -20,6 +20,12 @@ AUTHFAILURE = 'AuthFailure'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 异步检索任务还未完成，请稍后。
+FAILEDOPERATION_ASYNCSEARCHNOTCOMPLETED = 'FailedOperation.AsyncSearchNotCompleted'
+
+# 异步任务未完成。
+FAILEDOPERATION_ASYNCTASKNOTCOMPLETED = 'FailedOperation.AsyncTaskNotCompleted'
+
 # 告警策略通知模板已经绑定到了某个告警策略上。
 FAILEDOPERATION_BINDEDALARM = 'FailedOperation.BindedAlarm'
 
@@ -32,18 +38,27 @@ FAILEDOPERATION_INVALIDALARM = 'FailedOperation.InvalidAlarm'
 # 检索游标已失效或不存在。
 FAILEDOPERATION_INVALIDCONTEXT = 'FailedOperation.InvalidContext'
 
+# 离线存储保存时间不得少于7天。
+FAILEDOPERATION_INVALIDPERIOD = 'FailedOperation.InvalidPeriod'
+
 # 相同的日志集已存在。
 FAILEDOPERATION_LOGSETCONFLICT = 'FailedOperation.LogsetConflict'
 
 # 日志集下存在日志主题。
 FAILEDOPERATION_LOGSETNOTEMPTY = 'FailedOperation.LogsetNotEmpty'
 
+# 无效的Content。
+FAILEDOPERATION_MISSINGCONTENT = 'FailedOperation.MissingContent'
+
 # 修改的生命周期被禁止。
 FAILEDOPERATION_PERIODMODIFYFORBIDDEN = 'FailedOperation.PeriodModifyForbidden'
 
 # 查询语句运行失败。
 FAILEDOPERATION_QUERYERROR = 'FailedOperation.QueryError'
 
+# 读qps超过限制。
+FAILEDOPERATION_READQPSLIMIT = 'FailedOperation.ReadQpsLimit'
+
 # 查询超时。
 FAILEDOPERATION_SEARCHTIMEOUT = 'FailedOperation.SearchTimeout'
 
@@ -59,6 +74,15 @@ FAILEDOPERATION_TOPICCLOSED = 'FailedOperation.TopicClosed'
 # 日志主题已隔离。
 FAILEDOPERATION_TOPICISOLATED = 'FailedOperation.TopicIsolated'
 
+# 日志主题不支持该操作。
+FAILEDOPERATION_TOPICNOTSUPPORT = 'FailedOperation.TopicNotSupport'
+
+# 写qps超过限制。
+FAILEDOPERATION_WRITEQPSLIMIT = 'FailedOperation.WriteQpsLimit'
+
+# 写流量超过限制。
+FAILEDOPERATION_WRITETRAFFICLIMIT = 'FailedOperation.WriteTrafficLimit'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -74,6 +98,9 @@ INVALIDPARAMETER_ALARMNOTICECONFLICT = 'InvalidParameter.AlarmNoticeConflict'
 # 相同的采集配置规则已经存在。
 INVALIDPARAMETER_CONFIGCONFLICT = 'InvalidParameter.ConfigConflict'
 
+# 无效的Content。
+INVALIDPARAMETER_CONTENT = 'InvalidParameter.Content'
+
 # 指定日志主题已经存在索引规则。
 INVALIDPARAMETER_INDEXCONFLICT = 'InvalidParameter.IndexConflict'
 
@@ -95,6 +122,12 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 运行中的异步检索任务数目超限。
+LIMITEXCEEDED_ASYNCSEARCHTASK = 'LimitExceeded.AsyncSearchTask'
+
+# 异步任务数目超过限制。
+LIMITEXCEEDED_ASYNCTASK = 'LimitExceeded.AsyncTask'
+
 # 采集规则配置超过最大值限制。
 LIMITEXCEEDED_CONFIG = 'LimitExceeded.Config'
 
@@ -104,6 +137,9 @@ LIMITEXCEEDED_EXPORT = 'LimitExceeded.Export'
 # 并发查询超过限制，单topic并发最大值15。
 LIMITEXCEEDED_LOGSEARCH = 'LimitExceeded.LogSearch'
 
+# 日志大小超过限制。
+LIMITEXCEEDED_LOGSIZE = 'LimitExceeded.LogSize'
+
 # 日志集数量超出限制。
 LIMITEXCEEDED_LOGSET = 'LimitExceeded.Logset'
 
@@ -122,6 +158,9 @@ LIMITEXCEEDED_PARTITION = 'LimitExceeded.Partition'
 # 投递规则超出限制。
 LIMITEXCEEDED_SHIPPER = 'LimitExceeded.Shipper'
 
+# tag超过限制。
+LIMITEXCEEDED_TAG = 'LimitExceeded.Tag'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -158,6 +197,12 @@ RESOURCENOTFOUND_ALARMNOTEXIST = 'ResourceNotFound.AlarmNotExist'
 # 告警策略通知模板不存在。
 RESOURCENOTFOUND_ALARMNOTICENOTEXIST = 'ResourceNotFound.AlarmNoticeNotExist'
 
+# 异步检索任务不存在。
+RESOURCENOTFOUND_ASYNCSEARCHTASKNOTEXIST = 'ResourceNotFound.AsyncSearchTaskNotExist'
+
+# 异步任务不存在。
+RESOURCENOTFOUND_ASYNCTASKNOTEXIST = 'ResourceNotFound.AsyncTaskNotExist'
+
 # 指定的采集规则配置不存在。
 RESOURCENOTFOUND_CONFIGNOTEXIST = 'ResourceNotFound.ConfigNotExist'
 
